@@ -39,17 +39,17 @@ impl Observer for Log {
 #[test]
 fn init() {
     let _job = block_on(Job::init(
+        Log {},
         Some("foo".to_string()),
         JobData {},
         QueuedData {},
-        Log {},
     ))
     .unwrap();
 }
 
 #[test]
 fn init_without_id() {
-    let result = block_on(Job::init(None, JobData {}, QueuedData {}, Log {}));
+    let result = block_on(Job::init(Log {}, None, JobData {}, QueuedData {}));
     let err = result.err().unwrap();
     match err {
         InitError::EmptyId => {}
@@ -77,10 +77,10 @@ fn init_with_deferred_id() {
     }
 
     let _job = block_on(Job::init(
+        DeferredIdInitLog {},
         None,
         JobData {},
         QueuedData {},
-        DeferredIdInitLog {},
     ))
     .unwrap();
 }
@@ -112,10 +112,10 @@ fn on_init() {
     };
 
     let _job = block_on(Job::init(
+        &mut init_log,
         Some("foo".to_string()),
         JobData {},
         QueuedData {},
-        &mut init_log,
     ))
     .unwrap();
 
@@ -128,10 +128,10 @@ fn on_init() {
 #[test]
 fn read_id() {
     let job = block_on(Job::init(
+        Log {},
         Some("foo".to_string()),
         JobData {},
         QueuedData {},
-        Log {},
     ))
     .unwrap();
     let id = job.id();
@@ -142,10 +142,10 @@ fn read_id() {
 #[test]
 fn read_data() {
     let job = block_on(Job::init(
+        Log {},
         Some("foo".to_string()),
         JobData {},
         QueuedData {},
-        Log {},
     ))
     .unwrap();
     let _job_data = job.data();
@@ -155,13 +155,13 @@ fn read_data() {
 #[test]
 fn transition() {
     let job = block_on(Job::init(
+        Log {},
         Some("foo".to_string()),
         JobData {},
         QueuedData {},
-        Log {},
     ))
     .unwrap();
-    let _job = block_on(job.start(ProcessingData {})).unwrap();
+    let _job = block_on(job.start(Log {}, ProcessingData {})).unwrap();
 }
 
 #[test]
@@ -195,13 +195,13 @@ fn on_transition() {
     };
 
     let job = block_on(Job::init(
+        &mut transition_log,
         Some("foo".to_string()),
         JobData {},
         QueuedData {},
-        &mut transition_log,
     ))
     .unwrap();
-    let _job = block_on(job.start(ProcessingData {})).unwrap();
+    let _job = block_on(job.start(&mut transition_log, ProcessingData {})).unwrap();
 
     match transition_log.from {
         Some(state) => assert_eq!("Queued", state.to_string()),
